@@ -1,12 +1,7 @@
-from edusign.models.students import Students
-from edusign.models.professors import Professors
-from edusign.models.groups import Groups
 from edusign.models.courses import Courses
+from edusign.models.groups import Groups
+from edusign.models.professors import Professors
+from edusign.models.students import Students
 
 
-__all__ = [
-    "Students",
-    "Professors",
-    "Groups",
-    "Courses"
-]
+__all__ = ["Students", "Professors", "Groups", "Courses"]
