@@ -1,10 +1,13 @@
-import requests
-from edusign.utils import _EdusignAPI, EdusignAPIError
 from typing import List
 
+import requests
+
+from edusign.utils import _EdusignAPI
+from edusign.utils import EdusignAPIError
+
 
 class Groups(_EdusignAPI):
-    def create_group(self, group_name: str, student_list: List[str]):
+    def create(self, group_name: str, student_list: List[str]):
         """
         Create a group inside Edusign
 
